Module action

Module action 

Configuration and state data for handling an action set by consuemrs of input-actions.

Structs

Action
As in Rewired, an Action is a application/consumer facing event which a User can trigger via a Device.
Behavior
DigitalAxis
For Button events bound to Axis actions.
State
The state of an active action for a given user.

Enums

DigitalAxisReverse
Modifier applied when input is received in the opposite direction of the current flow.

Statics

ACTION_BEHAVIOR_DEFAULT_BUTTON

Type Aliases

Id