pub enum DigitalAxisReverse {
Snap,
InstantReverse,
}Expand description
Modifier applied when input is received in the opposite direction of the current flow.
Variants
Snap
Snap axis value to 0 and continue from there.
InstantReverse
Reverse the current value to the opposite sign and continue from there.