Configuration and state data for handling an action set by consuemrs of input-actions.
Structs
- Action
- As in Rewired, an Action is a application/consumer facing event which a
Usercan trigger via aDevice. - Behavior
- Digital
Axis - For
Buttonevents bound toAxisactions. - State
- The state of an active
actionfor a given user.
Enums
- Digital
Axis Reverse - Modifier applied when input is received in the opposite direction of the current flow.